pub struct EditorHandle { /* private fields */ }Expand description
A handle to programmatically interact with a CodeEditor instance.
Obtained via the on_ready callback prop on CodeEditor.
Implementations
Sourceimpl EditorHandle
impl EditorHandle
pub fn new( editor: Arc<Mutex<Editor>>, on_change: Option<Arc<dyn Fn(String) + Send + Sync>>, text_version: RwSignal<u64>, cursor_version: RwSignal<u64>, markers: RwSignal<Vec<Marker>>, marker_version: RwSignal<u64>, ) -> Self
Sourcepub fn insert_at_cursor(&self, text: &str)
pub fn insert_at_cursor(&self, text: &str)
Insert text at the current cursor position, replacing any active selection.
Sourcepub fn selected_text(&self) -> Option<String>
pub fn selected_text(&self) -> Option<String>
Return the currently selected text, or None if there is no selection.
Sourcepub fn set_markers(&self, markers: Vec<Marker>)
pub fn set_markers(&self, markers: Vec<Marker>)
Set error/warning markers on the editor content.
Sourcepub fn clear_markers(&self)
pub fn clear_markers(&self)
Clear all markers from the editor.